Module context

Module context 

Plugin execution context.

Uses a thread-local pattern similar to Helix editor’s Steel integration for implicit context access during plugin execution.

Structs

BuildContext
Build result information available to post-build hooks.
ContextGuard
Guard that sets context on creation and clears it on drop.
PluginContext
Context available during plugin execution.
TestContext
Test result information available to post-test hooks.

Functions

clear_context
Clear the current plugin context.
set_context
Set the current plugin context for this thread.
with_context
Access the current plugin context.
with_context_mut
Access the current plugin context mutably.