Plugin execution context.
Uses a thread-local pattern similar to Helix editor’s Steel integration for implicit context access during plugin execution.
Structs
- Build
Context - Build result information available to post-build hooks.
- Context
Guard - Guard that sets context on creation and clears it on drop.
- Plugin
Context - Context available during plugin execution.
- Test
Context - Test result information available to post-test hooks.
Functions
- clear_
context - Clear the current plugin context.
- set_
context - Set the current plugin context for this thread.
- with_
context - Access the current plugin context.
- with_
context_ mut - Access the current plugin context mutably.